==> koshoten.net-2.1.2.tar.gz: koshoten-net/admin/includes/languages/japanese/products_edit.php <==
<?php
/*
  products_edit.php
  2004/12/2
ǽ2005/7/26

ԡͭ²ҥɥ֥졼
δʿ
ryuhei@secondbrain.co.jp

  Released under the GNU General Public License
*/

define('HEADING_TITLE', 'ʴ');
define('TEXT_PRODUCTS_SEARCH', 'ʸ');
define('TEXT_SEARCH_RESULTS', '̰');
define('TEXT_EDIT_PRODUCT', 'ʥǡԽ');
define('TEXT_EDIT_PRODUCT_CONFIRM', 'ʥǡԽǧ');
define('TEXT_DELETE_PRODUCT_CONFIRM', 'ʥǡκǧ');

define('ERROR_CATALOG_IMAGE_DIRECTORY_NOT_WRITEABLE', '顼: Υǥ쥯ȥ˽񤭹ߤǤޤ: ' . DIR_FS_CATALOG_IMAGES);
define('ERROR_CATALOG_IMAGE_DIRECTORY_DOES_NOT_EXIST', '顼: Υǥ쥯ȥ꤬¸ߤޤ: ' . DIR_FS_CATALOG_IMAGES);
define('ERROR_PRODUCTS_IMAGE_DIRECTORY_NOT_WRITEABLE', '顼: ʲΥǥ쥯ȥ˽񤭹ߤǤޤ: ' . DIR_FS_CATALOG_IMAGES . DIR_WS_PRODUCTS_IMAGES);
define('ERROR_PRODUCTS_IMAGE_DIRECTORY_DOES_NOT_EXIST', '顼: ʲΥǥ쥯ȥ¸ߤޤ: ' . DIR_FS_CATALOG_IMAGES . DIR_WS_PRODUCTS_IMAGES);
define('ERROR_PRODUCTS_IMAGE_DIRECTORY2_NOT_WRITEABLE', '顼: ʲΥǥ쥯ȥ˽񤭹ߤǤޤ: ' . DIR_FS_CATALOG_IMAGES . DIR_WS_PRODUCTS_IMAGES . '%s');
define('ERROR_PRODUCTS_IMAGE_DIRECTORY2_DOES_NOT_EXIST', '顼: ʲΥǥ쥯ȥ¸ߤޤ: ' . DIR_FS_CATALOG_IMAGES . DIR_WS_PRODUCTS_IMAGES . '%s');
define('ERROR_NO_SEARCH_RESULTS', '顼: оݤξʤϤޤǤ');
define('ERROR_CATEGORIES_ID_IS_EMPTY', '顼: ƥ꡼ϤƤ');
define('ERROR_CATEGORY_DOES_NOT_EXIST', '顼: ꤷƥ꡼¸ߤޤ');
define('ERROR_PRODUCTS_NAME_IS_EMPTY', '顼: ̾ϤƤ');
define('ERROR_DELETE_PRODUCT_DOES_NOT_EXIST', '顼: оݤξʤ¸ߤޤ');

define('TEXT_LAST_ADDED_LIST', 'ǶϿ줿');
define('TEXT_LAST_MODIFIED_LIST', 'Ƕṹ줿');
define('TEXT_DELETE_PRODUCT', '뾦ʡ');

define('TABLE_HEADING_PRODUCTS_IMAGES', '');
define('TABLE_HEADING_CONTENTS', '');
define('TABLE_HEADING_ACTION', '');
define('TABLE_HEADING_PRODUCTS', 'ʡʤޤϾʿ');
define('TABLE_HEADING_DATE_ADDED', 'Ͽ');
define('TABLE_HEADING_LAST_MODIFIED', '');

define('TEXT_ALL_PRODUCTS_COUNT', 'ʿ');
define('TEXT_PRODUCTS_ON_SALE_COUNT', '߸ˤ');
define('TEXT_PRODUCTS_SOLD_OUT_COUNT', 'ڤ');
define('TEXT_CATEGORIES', 'ƥ꡼');
define('TEXT_PRODUCT_AVAILABLE', '߸ˤ');
define('TEXT_PRODUCT_NOT_AVAILABLE', 'ڤ');
define('TEXT_PRODUCTS_STATUS', 'ʥơ');
define('TEXT_PRODUCTS_DATE_AVAILABLE', 'ȯ');
define('TEXT_MANUFACTURER', KN_CFG_USE_MANUFACTURERS);
define('TEXT_PRODUCTS_NAME', '̾');
define('TEXT_PRODUCTS_SUBTITLE', '');
define('TEXT_PRODUCTS_SERIES_TITLE', '꡼̾');
define('TEXT_PRODUCTS_DESCRIPTION', 'ʸ');
define('TEXT_PRODUCTS_DESCRIPTION2', 'ʸ');
define('TEXT_PRODUCTS_AUTHOR', '');
define('TEXT_PRODUCTS_PUBLISHED', 'ǯ');
define('TEXT_PRODUCTS_PUBLISHERS', 'Ǹ');
define('TEXT_PRODUCTS_VOLUME', '');
define('TEXT_PRODUCTS_QUANTITY', '');
define('TEXT_PRODUCTS_MODEL', '');
define('TEXT_PRODUCTS_IMAGE', '');
define('TEXT_PRODUCTS_URL', 'URL');
define('TEXT_PRODUCTS_ISBN', 'ISBN');
define('TEXT_PRODUCTS_PRICE', '');
define('TEXT_PRODUCTS_WEIGHT', '');
define('TEXT_PRODUCTS_MEMO', 'ѥ');
define('TEXT_PRODUCTS_KEYWORDS', '');
define('TEXT_RECOMMENDATION_ORDER', '');
define('TEXT_RECOMMENDATION_ORDER_NOTE', '<small> ϡϤȤν֤ˤᾦʥɽޤ</small>');
define('TEXT_SORT_ORDER', 'Ǥ¤ӽ');
define('TEXT_PRODUCTS_TAX_CLASS_ID', 'Ǽ');

define('TEXT_LIST', 'ɽ');
define('TEXT_EDIT', 'Խ');
define('TEXT_DELETE', '');
define('TEXT_FILLER', '---');
define('TEXT_NO_IMAGES', 'ʤ');
define('TEXT_NO_PRODUCTS', '뾦ʤޤ');
define('TEXT_PRODUCTS_KEYWORDS_NOTE', 'ɤϥڡȾѡˤǶڤäʣϤǤޤ');

define('EMPTY_CATEGORY', 'ƥ꡼ޤ');
?>

==> koshoten.net-2.2.1.tar.gz: koshoten-net/admin/includes/languages/japanese/products_edit.php <==
<?php
/*
  products_edit.php
  2004/12/2
ǽ2005/9/24

ԡͭ²ҥɥ֥졼
δʿ
ryuhei@secondbrain.co.jp

  Released under the GNU General Public License
*/

define('HEADING_TITLE', 'ʴ');
define('TEXT_PRODUCTS_SEARCH', 'ʸ');
define('TEXT_SEARCH_RESULTS', '̰');
define('TEXT_EDIT_PRODUCT', 'ʥǡԽ');
define('TEXT_EDIT_PRODUCT_CONFIRM', 'ʥǡԽǧ');
define('TEXT_DELETE_PRODUCT_CONFIRM', 'ʥǡκǧ');

define('ERROR_CATALOG_IMAGE_DIRECTORY_NOT_WRITEABLE', '顼: Υǥ쥯ȥ˽񤭹ߤǤޤ: ' . DIR_FS_CATALOG_IMAGES);
define('ERROR_CATALOG_IMAGE_DIRECTORY_DOES_NOT_EXIST', '顼: Υǥ쥯ȥ꤬¸ߤޤ: ' . DIR_FS_CATALOG_IMAGES);
define('ERROR_PRODUCTS_IMAGE_DIRECTORY_NOT_WRITEABLE', '顼: ʲΥǥ쥯ȥ˽񤭹ߤǤޤ: ' . DIR_FS_CATALOG_IMAGES . DIR_WS_PRODUCTS_IMAGES);
define('ERROR_PRODUCTS_IMAGE_DIRECTORY_DOES_NOT_EXIST', '顼: ʲΥǥ쥯ȥ¸ߤޤ: ' . DIR_FS_CATALOG_IMAGES . DIR_WS_PRODUCTS_IMAGES);
define('ERROR_PRODUCTS_IMAGE_DIRECTORY2_NOT_WRITEABLE', '顼: ʲΥǥ쥯ȥ˽񤭹ߤǤޤ: ' . DIR_FS_CATALOG_IMAGES . DIR_WS_PRODUCTS_IMAGES . '%s');
define('ERROR_PRODUCTS_IMAGE_DIRECTORY2_DOES_NOT_EXIST', '顼: ʲΥǥ쥯ȥ¸ߤޤ: ' . DIR_FS_CATALOG_IMAGES . DIR_WS_PRODUCTS_IMAGES . '%s');
define('ERROR_NO_SEARCH_RESULTS', '顼: оݤξʤϤޤǤ');
define('ERROR_CATEGORIES_ID_IS_EMPTY', '顼: ƥ꡼ϤƤ');
define('ERROR_CATEGORY_DOES_NOT_EXIST', '顼: ꤷƥ꡼¸ߤޤ');
define('ERROR_PRODUCTS_NAME_IS_EMPTY', '顼: ̾ϤƤ');
define('ERROR_DELETE_PRODUCT_DOES_NOT_EXIST', '顼: оݤξʤ¸ߤޤ');

define('TEXT_LAST_ADDED_LIST', 'ǶϿ줿');
define('TEXT_LAST_MODIFIED_LIST', 'Ƕṹ줿');
define('TEXT_DELETE_PRODUCT', '뾦ʡ');

define('TABLE_HEADING_PRODUCTS_IMAGES', '');
define('TABLE_HEADING_CONTENTS', '');
define('TABLE_HEADING_ACTION', '');
define('TABLE_HEADING_PRODUCTS', 'ʡʤޤϾʿ');
define('TABLE_HEADING_DATE_ADDED', 'Ͽ');
define('TABLE_HEADING_LAST_MODIFIED', '');

define('TEXT_ALL_PRODUCTS_COUNT', 'ʿ');
define('TEXT_PRODUCTS_ON_SALE_COUNT', '߸ˤ');
define('TEXT_PRODUCTS_SOLD_OUT_COUNT', 'ڤ');
define('TEXT_CATEGORIES', 'ƥ꡼');
define('TEXT_PRODUCT_AVAILABLE', '߸ˤ');
define('TEXT_PRODUCT_NOT_AVAILABLE', 'ڤ');
define('TEXT_PRODUCTS_STATUS', 'ʥơ');
define('TEXT_PRODUCTS_DATE_AVAILABLE', 'ȯ');
define('TEXT_MANUFACTURER', KN_CFG_USE_MANUFACTURERS);
define('TEXT_PRODUCTS_NAME', '̾');
define('TEXT_PRODUCTS_SUBTITLE', '');
define('TEXT_PRODUCTS_SERIES_TITLE', '꡼̾');
define('TEXT_PRODUCTS_DESCRIPTION', 'ʸ');
define('TEXT_PRODUCTS_DESCRIPTION2', 'ʸ');
define('TEXT_PRODUCTS_AUTHOR', '');
define('TEXT_PRODUCTS_PUBLISHED', 'ǯ');
define('TEXT_PRODUCTS_PUBLISHERS', 'Ǹ');
define('TEXT_PRODUCTS_VOLUME', '');
define('TEXT_PRODUCTS_QUANTITY', '߸˿');
define('TEXT_PRODUCTS_MODEL', '');
define('TEXT_PRODUCTS_IMAGE', '');
define('TEXT_PRODUCTS_URL', 'URL');
define('TEXT_PRODUCTS_ISBN', 'ISBN');
define('TEXT_PRODUCTS_PRICE', '');
define('TEXT_PRODUCTS_WEIGHT', '');
define('TEXT_PRODUCTS_MEMO', 'ѥ');
define('TEXT_PRODUCTS_KEYWORDS', '');
define('TEXT_RECOMMENDATION_ORDER', '');
define('TEXT_RECOMMENDATION_ORDER_NOTE', '<small> ϤȤν֤ˤᾦʥɽޤ</small>');
define('TEXT_SORT_ORDER', 'Ǥ¤ӽ');
define('TEXT_SORT_ORDER_NOTE', '<small> ͤξ˾ʰɽޤά</small>');
define('TEXT_PRODUCTS_TAX_CLASS_ID', 'Ǽ');

define('TEXT_AUTO_NUM', 'ư');
define('TEXT_LIST', 'ɽ');
define('TEXT_EDIT', 'Խ');
define('TEXT_DELETE', '');
define('TEXT_FILLER', '---');
define('TEXT_NO_IMAGES', 'ʤ');
define('TEXT_NO_PRODUCTS', '뾦ʤޤ');
define('TEXT_PRODUCTS_KEYWORDS_NOTE', 'ɤϥڡǶڤäʣϤǤޤ');

define('EMPTY_CATEGORY', 'ƥ꡼ޤ');
?>
